==> pf4-component-mapper-3.20.0.tgz: package/esm/select/select/input.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["inputRef", "isSearchable", "isDisabled", "getInputProps", "value"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import './input.css';

var getInputString = function getInputString(filter, value) {
  if (typeof filter === 'string') {
    return filter;
  }

  if (typeof value === 'string') {
    return value;
  }

  if (Array.isArray(value) && typeof value[0] === 'string') {
    return value[0];
  }

  return '';
};

var Input = function Input(_ref) {
  var inputRef = _ref.inputRef,
      isSearchable = _ref.isSearchable,
      isDisabled = _ref.isDisabled,
      getInputProps = _ref.getInputProps,
      value = _ref.value,
      props = _objectWithoutProperties(_ref, _excluded);

  var inputProps = getInputProps({
    disabled: isDisabled
  });
  var initialInputValue = getInputString(inputProps.value, value);
  return /*#__PURE__*/React.createElement("input", _extends({
    value: ""
  }, props, {
    className: "pf-c-form-control pf-c-select__toggle-typeahead",
    ref: inputRef
  }, _objectSpread(_objectSpread({}, inputProps), {}, {
    value: initialInputValue,
    onKeyDown: function onKeyDown(event) {
      event.stopPropagation();

      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      inputProps.onKeyDown.apply(inputProps, [event].concat(args));
    },
    onChange: inputProps.onChange || Function
  })));
};

Input.propTypes = {
  inputRef: PropTypes.shape({
    current: PropTypes.instanceOf(Element)
  }),
  isSearchable: PropTypes.bool,
  isDisabled: PropTypes.bool,
  getInputProps: PropTypes.func.isRequired,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.arrayOf(PropTypes.string)])
};
export default Input;

==> pf4-component-mapper-3.23.0.tgz: package/esm/select/select/input.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["inputRef", "isSearchable", "isDisabled", "getInputProps", "value"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import '@patternfly/react-styles/css/components/TextInputGroup/text-input-group.css';
import './input.css';

var getInputString = function getInputString(filter, value) {
  if (typeof filter === 'string') {
    return filter;
  }

  if (typeof value === 'string') {
    return value;
  }

  if (Array.isArray(value) && typeof value[0] === 'string') {
    return value[0];
  }

  return '';
};

var Input = function Input(_ref) {
  var inputRef = _ref.inputRef,
      isSearchable = _ref.isSearchable,
      isDisabled = _ref.isDisabled,
      getInputProps = _ref.getInputProps,
      value = _ref.value,
      props = _objectWithoutProperties(_ref, _excluded);

  var inputProps = getInputProps({
    disabled: isDisabled
  });
  var initialInputValue = getInputString(inputProps.value, value);
  return /*#__PURE__*/React.createElement("div", {
    className: "ddorg__pf4-component-mapper__select-input-wrapper pf-v5-c-text-input-group pf-m-typeahead"
  }, /*#__PURE__*/React.createElement("input", _extends({
    value: ""
  }, props, {
    className: "pf-v5-c-text-input-group__text-input",
    ref: inputRef
  }, _objectSpread(_objectSpread({}, inputProps), {}, {
    value: initialInputValue,
    onKeyDown: function onKeyDown(event) {
      event.stopPropagation();

      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      inputProps.onKeyDown.apply(inputProps, [event].concat(args));
    },
    onChange: inputProps.onChange || Function
  }))));
};

Input.propTypes = {
  inputRef: PropTypes.shape({
    current: PropTypes.instanceOf(Element)
  }),
  isSearchable: PropTypes.bool,
  isDisabled: PropTypes.bool,
  getInputProps: PropTypes.func.isRequired,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.arrayOf(PropTypes.string)])
};
export default Input;
